# Disclaimer - This shit ain't donee
# Coolered
## A better [dslackw/colored](https://github.com/dslackw/colored)
I read the readme of dslackw/colored for Python, and thought it was too complicated. This will be an interface so simple you memorize it immediately.

## Example
```
# Colors
red("This is red")
green("This is green")
blue("This is blue")

# Backgrounds
blue("Blue with a red background").on_red()
green("This isn't readable").on_green()

# That's it
```

## Color reference chart

## Installation
```
pip install coolered
```
## Uninstallation
```
pip uninstall coolered
```
